==> custom_pages-v1.12.7.zip: custom_pages/messages/nl/view.php <==
<?php
return [
  '<strong>Copy</strong> Custom Page' => 'Aangepaste pagina <strong>kopiëren</strong>',
  '<strong>Info: </strong> Pages marked as "Admin Only" are not shown in the stream!' => '<strong> Info:</strong> pagina\'s die zijn gemarkeerd als "Alleen voor beheerders" worden niet weergegeven in de updates!',
  'Add new {pageType}' => 'Toevoegen van een nieuwe {pageType}',
  'By setting an url shortcut value, you can create a better readable url for your page. If <b>URL Rewriting</b> is enabled on your site, the value \'mypage\' will result in an url \'www.example.de/p/mypage\'.' => 'Door een url-snelkoppeling in te stellen, kunt u een beter leesbare URL voor uw pagina maken. Als <b>URL-herschrijving</b> is ingeschakeld op uw site, resulteert de waarde \'Mijnpagina\' in een URL \'www.example.de/p/mijnpagina\'.',
  'Configuration' => 'Configuratie',
  'Copy' => 'Kopiëren',
  'Create' => 'Maak',
  'Create new template' => 'Maak een nieuwe sjabloon',
  'Delete' => 'Verwijder',
  'Edit template' => 'Bewerk de sjabloon',
  'Empty' => 'leeg',
  'Exit Edit Mode' => 'Bewerkingsmodus verlaten',
  'Here you can configure the general settings of your {pageLabel}.' => 'Hier kunt u de algemene instellingen van uw {pageLabel} configureren.',
  'Inline Editor' => 'Inline Editor',
  'Multiple' => 'Meerdere',
  'Open page...' => 'Open bladzijde...',
  'Page configuration' => 'Pagina-configuratie',
  'Save' => 'Bewaar',
  'Settings' => 'Instellingen',
  'The abstract will be used as stream entry content to promote the actual page. 
                        If no abstract is given or the page is only visible for admins, no stream entry will be created.' => 'De samenvatting wordt gebruikt als inhoud voor nieuwsoverzicht om de eigenlijke pagina te promoten. Ontbreekt de samenvatting of is de pagina alleen zichtbaar is voor beheerders, dan wordt geen nieuwsitem gemaakt.',
  'This page lists all available custom content entries.' => 'Deze pagina laat alle beschikbare, aangepaste items zien',
  'This section has no editable elements.' => 'Deze sectie heeft geen bewerkbare elementen.',
  'View not found' => 'View niet gevonden',
  'You don\'t have permission to access the page' => 'U heeft geen toestemming om de pagina te openen',
  'You need to be a system administrator to edit this URL' => 'U moet een systeembeheerder zijn om deze URL te kunnen bewerken',
  'e.g. allowfullscreen allow="camera; microphone"' => 'bijvoorbeeld allowfullscreen allow="camera; microphone"',
  'e.g. http://www.example.de' => 'bijv. http://www.voorbeeld.nl',
  'none' => 'Geen',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/nl/view.php <==
<?php
return [
  '<strong>Copy</strong> Custom Page' => 'Aangepaste pagina <strong>kopiëren</strong>',
  '<strong>Info: </strong> Pages marked as "Admin Only" are not shown in the stream!' => '<strong> Info:</strong> pagina\'s die zijn gemarkeerd als "Alleen voor beheerders" worden niet weergegeven in de updates!',
  'Add new {pageType}' => 'Toevoegen van een nieuwe {pageType}',
  'By setting an url shortcut value, you can create a better readable url for your page. If <b>URL Rewriting</b> is enabled on your site, the value \'mypage\' will result in an url \'www.example.de/p/mypage\'.' => 'Door een url-snelkoppeling in te stellen, kunt u een beter leesbare URL voor uw pagina maken. Als <b>URL-herschrijving</b> is ingeschakeld op uw site, resulteert de waarde \'Mijnpagina\' in een URL \'www.example.de/p/mijnpagina\'.',
  'Configuration' => 'Configuratie',
  'Copy' => 'Kopiëren',
  'Create' => 'Maak',
  'Create new template' => 'Maak een nieuwe sjabloon',
  'Delete' => 'Verwijder',
  'Edit template' => 'Bewerk de sjabloon',
  'Empty' => 'leeg',
  'Exit Edit Mode' => 'Bewerkingsmodus verlaten',
  'Here you can configure the general settings of your {pageLabel}.' => 'Hier kunt u de algemene instellingen van uw {pageLabel} configureren.',
  'Inline Editor' => 'Inline Editor',
  'Multiple' => 'Meerdere',
  'Open page...' => 'Open bladzijde...',
  'Page configuration' => 'Pagina-configuratie',
  'Save' => 'Bewaar',
  'Settings' => 'Instellingen',
  'The abstract will be used as stream entry content to promote the actual page.
                        If no abstract is given or the page is only visible for admins, no stream entry will be created.' => 'De samenvatting zal als starttekst voor de berichten worden gebruikt om de eigenlijke pagina te promoten. Als er geen samenvatting is opgegeven of als de pagina alleen zichtbaar is voor beheerders, wordt er geen nieuwsbericht aangemaakt.',
  'This page lists all available custom content entries.' => 'Deze pagina laat alle beschikbare, aangepaste items zien',
  'This section has no editable elements.' => 'Deze sectie heeft geen bewerkbare elementen.',
  'View not found' => 'View niet gevonden',
  'You don\'t have permission to access the page' => 'U heeft geen toestemming om de pagina te openen',
  'You need to be a system administrator to edit this URL' => 'U moet een systeembeheerder zijn om deze URL te kunnen bewerken',
  'e.g. allowfullscreen allow="camera; microphone"' => 'bijvoorbeeld allowfullscreen allow="camera; microphone"',
  'e.g. http://www.example.de' => 'bijv. http://www.voorbeeld.nl',
  'none' => 'Geen',
];
